# Authors:
#   Jason Gerard DeRose <jderose@redhat.com>
#
# wehjit: A Python web-widget library
# Copyright (C) 2009  Red Hat
#
# This file is part of `wehjit`.
#
# `wehjit` is free software: you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# `wehjit` is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# `wehjit`.  If not, see <http://www.gnu.org/licenses/>.

"""
Welcome.
"""

from wehjit import __version__, Container, StaticProp

title = 'Welcome to wehjit %s!' % __version__
apidoc = 'http://jderose.fedorapeople.org/wehjit/%s/apidoc/' % __version__

def create_page(app):
    class Welcome(Container):
        xml = """
        <div
            xmlns:py="http://genshi.edgewall.org/"
            class="${css_classes}"
            id="${id}"
        >

        <p>
        <code>wehjit</code> is a <a href="http://python.org/">Python</a> library
        for building XHTML widgets for web applications and web pages.  It
        encapusaltes the XML (a <a href="http://genshi.edgewall.org/">Genshi</a>
        template), CSS, and JavaScript for each widget into a plugin.  A
        tutorial plus full API documentation is <a href="%s">available here</a>.
        </p>

        <p>
        <code>wehjit</code> has some unique features in how it handless CSS.
        When you create an application (a collection of pages),
        <code>wehjit</code> will render a single CSS file containing the styles
        for all the widget plugins that your application uses.  Each widget
        plugin typically provides some default style, but you can override any
        of this default style via a simple
        <a href="http://docs.python.org/library/json.html">JSON-encoded</a>
        configuration file.  Even with overrides, a single CSS file is rendered.
        </p>

        <p>
        The details are best explained with an example.  The table below
        contains the exact style information used by these demo pages.  The left
        column contains the total style definition in JavaScript Object Notation
        (JSON).  The right column contains the same style information rendered
        as CSS.
        </p>

        <table>
        <tr>
        <th>Style config dumped to JSON</th>
        <th>Rendered CSS</th>
        </tr>
        <tr>
        <td py:content="style_json.generate()" />
        <td py:content="style_css.generate()" />
        </tr>
        </table>

        </div>
        """ % apidoc

        style_json = StaticProp(name='style_json')
        style_css = StaticProp(name='style_css')

        def __init__(self, **kw):
            super(Welcome, self).__init__(**kw)
            self._style_json = self.new('Highlighter', lexer='js')
            self._style_css = self.new('Highlighter', lexer='css')
            self.add(self._style_json)

        def _finalize_parent(self):
            super(Welcome, self)._finalize_parent()
            self._style_json.code = self.app.styles.dumps(indent=2)
            self._style_css.code = open(
                self.app.assets.asset_file('wehjit.css'), 'r'
            ).read()

        style = (
                ('', (
                ('width', '%(width_content)s'),
            )),
            ('table', (
                ('border-collapse', 'separate'),
                ('border-spacing', '2px'),
            )),

            ('th', (
                ('background-color', '#ddd'),
                ('padding', '0.5em'),
            )),

            ('td', (
                ('vertical-align', 'top'),
                ('background-color', '#eee'),
                ('padding', '0.5em'),
            )),
        )

    app.widgets.register(Welcome)

    page = app.new('PageApp')
    page.view.add(
        app.new('Welcome')
    )
    return page
