# Authors:
#   Jason Gerard DeRose <jderose@redhat.com>
#
# wehjit: A Python web-widget library
# Copyright (C) 2009  Red Hat
#
# This file is part of `wehjit`.
#
# `wehjit` is free software: you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# `wehjit` is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# `wehjit`.  If not, see <http://www.gnu.org/licenses/>.

"""
Using Forms.
"""

def create_page(app):
    page = app.new('PageApp')
    page.actions.add(
        app.new('Submit', label='Add User')
    )

    # Users menu
    m = app.new('Menu', label='Users')
    page.menuset.add(m)
    m.add(
        app.new('MenuItem', label='Add User'),
        app.new('MenuItem', label='Find/Edit/Delete Users'),
        app.new('MenuItem', label='Add User Group'),
        app.new('MenuItem', label='Find/Edit/Delete User Groups'),
    )

    # Host menu
    m = app.new('Menu', label='Hosts')
    page.menuset.add(m)
    m.add(
        app.new('MenuItem', label='Add Host'),
        app.new('MenuItem', label='Find/Edit/Delete Hosts'),
        app.new('MenuItem', label='Add User Host Group'),
        app.new('MenuItem', label='Find/Edit/Delete Host Groups'),
    )

    # Permissions menu
    m = app.new('Menu', label='Permissions')
    page.menuset.add(m)
    m.add(
        app.new('MenuItem', label='Add Role'),
        app.new('MenuItem', label='Find/Edit/Delete Roles'),
        app.new('MenuItem', label='Add User Host ACI'),
        app.new('MenuItem', label='Find/Edit/Delete ACI'),
    )

    # Configuration menu
    m = app.new('Menu', label='Configuration')
    page.menuset.add(m)
    m.add(
        app.new('MenuItem', label='AutoMount'),
        app.new('MenuItem', label='DNS'),
        app.new('MenuItem', label='Services'),
    )

    form = page.view.new_child('Form')
    # Identity Details
    f = form.new_child('Fieldset', label='Identity Details')
    t = app.new('FieldTable')
    f.add(t)
    t.add(
        app.new('TextRow', label='Title', value='Overlord of Operations'),
        app.new('TextRow', label='First Name', required=True, value='John'),
        app.new('TextRow', label='Last Name', required=True, value='Doe'),
        app.new('TextRow', label='Login', required=True, value='jdoe'),
        app.new('TextRow', label='Email', value='jdoe@example.com'),
        app.new('TextRow', label='Phone'),
        app.new('TextAreaRow', label='Address'),
    )

    # Account Details
    f = form.new_child('Fieldset', label='Account Details')
    t = app.new('FieldTable')
    f.add(t)
    t.add(
        app.new('PasswordRow', error='Error: the passwords do not match'),
        app.new('SelectRow', label='Account Status', value='active',
            options=(
                ('active', 'Active'),
                ('disabled', 'Disabled'),
            ),
        ),
        app.new('SelectRow', label='Allow SSH', value='0'),
        app.new('SelectRow', label='SHELL', value='dash',
            options=(
                ('bash', '/bin/bash'),
                ('dash', '/bin/dash'),
                ('sh', '/bin/sh'),
            ),
        ),
        app.new('TextRow', label='Home Directory', value='/home/jdoe'),
        app.new('TextRow', label='Principal', value='jdoe@EXAMPLE.COM'),
        app.new('TextRow', label='GECOS'),
        app.new('TextRow', label='UID'),
    )

    return page
