# Authors:
#   Jason Gerard DeRose <jderose@redhat.com>
#
# wehjit: A Python web-widget library
# Copyright (C) 2009  Red Hat
#
# This file is part of `wehjit`.
#
# `wehjit` is free software: you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# `wehjit` is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# `wehjit`.  If not, see <http://www.gnu.org/licenses/>.

"""
Content layout.
"""

import genshi
from wehjit import base, builtins
from wehjit.state import *


class Content(base.Widget):
    def __init__(self, **kw):
        super(Content, self).__init__(**kw)
        self.__map = dict(
            html=genshi.HTML,
            xml=genshi.XML,
        )

    content = Dynamic('content')
    kind = Dynamic('kind', default='html')

    @DynamicProp
    def content_stream(self):
        if not self.content:
            return
        if self.kind in self.__map:
            return self.__map[self.kind](self.content)
        return self.content

    xml = """
    <div
        xmlns:py="http://genshi.edgewall.org/"
        class="${klass}"
        id="${id}"
        py:content="content_stream"
    />
    """

    style = (
        ('', (
            ('width', '%(width_content)s'),
        )),
    )


builtins.register(Content)
